Stan Math Library: stan/math/prim/scal/meta/partials_return_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

partials_return_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_PARTIALS_RETURN_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_PARTIALS_RETURN_TYPE_HPP
3
4 #include <stan/math/prim/scal/meta/partials_type.hpp>
5 #include <stan/math/prim/scal/meta/scalar_type.hpp>
6 #include <boost/math/tools/promotion.hpp>
7
8 namespace stan {
9
10 template <typename T1,
11 typename T2 = double,
12 typename T3 = double,
13 typename T4 = double,
14 typename T5 = double,
15 typename T6 = double>
16 struct partials_return_type {
17 typedef typename
18 boost::math::tools::promote_args
19 <typename partials_type<typename scalar_type<T1>::type>::type,
20 typename partials_type<typename scalar_type<T2>::type>::type,
21 typename partials_type<typename scalar_type<T3>::type>::type,
22 typename partials_type<typename scalar_type<T4>::type>::type,
23 typename partials_type<typename scalar_type<T5>::type>::type,
24 typename partials_type<typename scalar_type<T6>::type>::type>
25 ::type
26 type;
27 };
28
29
30 }
31 #endif
32
stan
Definition: log_sum_exp.hpp:8
partials_type.hpp
stan::partials_return_type
Definition: partials_return_type.hpp:16
stan::partials_type
Definition: partials_type.hpp:7
scalar_type.hpp
stan::partials_return_type::type
boost::math::tools::promote_args< typename partials_type< typename scalar_type< T1 >::type >::type, typename partials_type< typename scalar_type< T2 >::type >::type, typename partials_type< typename scalar_type< T3 >::type >::type, typename partials_type< typename scalar_type< T4 >::type >::type, typename partials_type< typename scalar_type< T5 >::type >::type, typename partials_type< typename scalar_type< T6 >::type >::type >::type type
Definition: partials_return_type.hpp:26

[ Stan Home Page ] © 2011–2016, Stan Development Team.